// email_list.js

/*
Basic 3 questions to ask yourself?
1. did I define it?
2. did I give it value?
3. did I return it?
*/

/*
form elements: first_name, email_1, email_2
actions: joinList, clearForm, eventHandler
*/

/* 
How are we going to DEFINE our functions?
1. use the function keyword "pure javascript"
2. use an es6 arrow function => "short code way of defining a function" "jQuery preferred"
*/

// assign the $ decorator to an entity that returns the first elements<> matching our selector<>

const $ = selector => document.querySelector(selector);

// create an event to handle the form submission
// when we CALL the selectors, we will ALWAYS decorate the selector name with the $, so that they are constant and can not change

// method 1 uses the function keyword
// const joinList = function evt { stuff here; } 

// method 2 uses the arrow function =>
const joinList = evt => {
    // get the user inputs from the html form
    // form elements: first_name, email_1, email_2
    const email1 = $("#email_1").value; // "" blank -> error
    const email2 = $("#email_2").value; // email2 = "" -> error
    const firstName = $("#first_name").value; // camelCase = underscore_case
    

    // testing and debugging
    // check the user inputs for validation
    // create a return variable for true/false
    // use the let keyword to define a variable in js
    let isValid = true; // = assigns

    // test using an if statement
    // if (condition) { true } 
    // if (condition) { true } else { false }
    // if (condition) { true } else if (retest true) ... else { false }
    // test to see if email1 has a value
    if ( email1 == "" ) {
        $("#email_1_error").textContent = "Email is required.";
        isValid = false;
    }
    // else keyword to clear the error value
    else {
        $("#email_1_error").textContent = "";
    }

    // test to see if the email2 value is the SAME as email1
    if (email1 != email2) {
        $("#email_2_error").textContent = "Emails must match";
        isValid = false;
    }
    else {
        $("#email_2_error").textContent = "";
    }

    // firstName is required
    if ( firstName == "" ) {
        $("#first_name_error").textContent = "First Name is required.";
        isValid = false;
    }
    else {
        $("#first_name_error").textContent = "";
    }


    // cancel the submit action if the user did not fill in the data
    // if ANY of the test conditions meet false then we need to prevent the submit button from doing a form submission
    // isValid = false;

    // if ( isValid == false ) or if ( !isValid ) 

    if ( !isValid ) {
        evt.preventDefault();
    }

} // joinList

// Define a clear form so the form is empty for the next input
const clearForm = () => {  // () means there are no params to pass to
    // clear the text boxes
    $("#email_1").value = "";
    $("#email_2").value = "";
    $("#first_name").value = "";

    // clear the span tags (error messages)
    $("#email_1_error").textContent = "*";
    $("#email_2_error").textContent = "*";
    $("#first_name_error").textContent = "*";

    // cursor position
    $("#email_1").focus();
} // clearForm

// Listener that listens to the action from the html and calls the event from js
// hook -> event listener

document.addEventListener(
    // param 1 type
    "DOMContentLoaded", 
    
    // param 2 listener
    () => {
        // const html definition.add("action","js element")
        $("#join_list").addEventListener("click", joinList);
        $("#clear_form").addEventListener("click", clearForm); 

        // set the cursor on the initial forn load
        $("#email_1").focus();
        alert("Please fill out the form")

    } // param 2

) // document params

// email_list.js EOF