// slide_show.js

const $ = selector => document.querySelector(selector)

// dataset or array to hold our image filenames
// arrays are defined by using the []
// arrays are indexed so you can call an element by its index number
/// ["Bob", "Mary", "Sue"] length(3) index[0:2] Bob[0] Mary[1] Sue[2]
const imageCache = []; // empty array to dynamically add images.jpg files to

// define our global variables that we are going to use in our slide show
let imageCounter = 0;
let timer = null; // milliseconds 4 seconds set timer = 4000
let image = null; // placeholder for the jpg filename "individual"

// the img selector<html>/element<js>
/// <img src="value" alt="">
/// <img src="images/deer.jpg" alt="Deer in the Forest">
/// const joinList <js> = $ #join_list <html>
const mainImage = $("#main_image");

// the h2<html>/element<js> for the images caption
const caption = $("#caption");

// define a function to run the slide show
/// imageCounter,image,src,alt,caption
const runSlideShow = () => {
    imageCounter = (imageCounter + 1) % imageCache.length; // number of images will be created using the length of cached images
    // ["bison.jpg"[0],"deer.jpg"[1],"hero.jpg"[2]]
    image = imageCache[imageCounter]; //imageCache[0]->imageCache[1]->imageCache[2]->break
    mainImage.src = image.src;
    mainImage.alt = image.alt;
    caption.textContent = image.alt;
}; // runSlideShow()

// document Listener to "listen" for an event action
/// "click" -> a single button click will call the event
/// links to the images <a href="">
/// start/pause slideshow
/// once the slide show starts, how long "timer" do we want to show each image
document.addEventListener(
    "DOMContentLoaded", //param 1
    // function that processes the image links -> param 2
    () => {
     
        // step 1 for param 2 is to find all the <a> tags in the source
        const links = $("#image_list").querySelectorAll("a");

        // step 2 is to process those found image links
        /// old concept for (control, condition, increment) future_value.js
        /// new concept for the for loop
        //// for ( let link of links ) -> let x of ys
        //// x is the local variable to use in the scope
        //// ys is the data set (array in js) -> links
        /// once we get all the links we need to add images to cache array

        for ( let link of links) {
            // scope -> use link variable
            image = new Image(); // new keyword ALWAYS creates a new object, it never UPDATES an existing object
            image.src = link.href;
            image.alt = link.title;

            // add the new oject for Image to array
            imageCache[imageCache.length] = image;
        } // for(links)

        // add 2 sub events to the parent event
        /// slide_show subevent 1 -> start button "click"
        $("#start").addEventListener("click", 
            () => {
                runSlideShow(); // defined that function above
                timer = setInterval(runSlideShow, 2000);
                $("#start").disabled = true; // <button id="Start" disabled>
                $("#pause").disabled = false;
            } // param 2
         ); // start

        /// slide_show subevent 2 -> pause button "click"
        $("#pause").addEventListener("click",
            () => {
                clearInterval(timer);
                $("#start").disabled = false; // <button id="Start" disabled>
                $("#pause").disabled = true;
            } // param 2
        ); //pause

    } // param2

); // document

// EOF slide_show.js